from .entities import (
    Constructor,
    Method,
)
from .parser import TDApiParser
